@@ -7,15 +7,12 @@
 #'
 #' @keywords internal
 glmnet_validate_external_tauc <- function(
-  object, x_tr, x_te, y_tr, y_te,
-  tauc.type, tauc.time) {
+    object, x_tr, x_te, y_tr, y_te,
+    tauc.type, tauc.time) {
   lp_tr <- as.vector(predict(object, newx = x_tr, type = "link"))
   lp_te <- as.vector(predict(object, newx = x_te, type = "link"))
 
-  tauc_list <- switch(
-
-    tauc.type,
-
+  tauc_list <- switch(tauc.type,
     CD = {
       AUC.cd(
         Surv.rsp = y_tr, Surv.rsp.new = y_te,
@@ -23,7 +20,6 @@ glmnet_validate_external_tauc <- function(
         times = tauc.time
       )
     },
-
     SZ = {
       AUC.sh(
         Surv.rsp = y_tr, Surv.rsp.new = y_te,
@@ -31,7 +27,6 @@ glmnet_validate_external_tauc <- function(
         times = tauc.time
       )
     },
-
     UNO = {
       AUC.uno(
         Surv.rsp = y_tr, Surv.rsp.new = y_te,
@@ -52,15 +47,12 @@ glmnet_validate_external_tauc <- function(
 #'
 #' @keywords internal
 ncvreg_validate_external_tauc <- function(
-  object, x_tr, x_te, y_tr, y_te,
-  tauc.type, tauc.time) {
+    object, x_tr, x_te, y_tr, y_te,
+    tauc.type, tauc.time) {
   lp_tr <- as.vector(predict(object, X = x_tr, type = "link"))
   lp_te <- as.vector(predict(object, X = x_te, type = "link"))
 
-  tauc_list <- switch(
-
-    tauc.type,
-
+  tauc_list <- switch(tauc.type,
     CD = {
       AUC.cd(
         Surv.rsp = y_tr, Surv.rsp.new = y_te,
@@ -68,7 +60,6 @@ ncvreg_validate_external_tauc <- function(
         times = tauc.time
       )
     },
-
     SZ = {
       AUC.sh(
         Surv.rsp = y_tr, Surv.rsp.new = y_te,
@@ -76,7 +67,6 @@ ncvreg_validate_external_tauc <- function(
         times = tauc.time
       )
     },
-
     UNO = {
       AUC.uno(
         Surv.rsp = y_tr, Surv.rsp.new = y_te,
@@ -98,15 +88,12 @@ ncvreg_validate_external_tauc <- function(
 #'
 #' @keywords internal
 penalized_validate_external_tauc <- function(
-  object, x_tr, x_te, y_tr, y_te,
-  tauc.type, tauc.time) {
+    object, x_tr, x_te, y_tr, y_te,
+    tauc.type, tauc.time) {
   lp_tr <- as.vector(object@"lin.pred")
   lp_te <- as.vector(x_te %*% as.matrix(object@"penalized"))
 
-  tauc_list <- switch(
-
-    tauc.type,
-
+  tauc_list <- switch(tauc.type,
     CD = {
       AUC.cd(
         Surv.rsp = y_tr, Surv.rsp.new = y_te,
@@ -114,7 +101,6 @@ penalized_validate_external_tauc <- function(
         times = tauc.time
       )
     },
-
     SZ = {
       AUC.sh(
         Surv.rsp = y_tr, Surv.rsp.new = y_te,
@@ -122,7 +108,6 @@ penalized_validate_external_tauc <- function(
         times = tauc.time
       )
     },
-
     UNO = {
       AUC.uno(
         Surv.rsp = y_tr, Surv.rsp.new = y_te,
